SWDEV-545870 - Remove beta warning in HIP Graph APIs (#286)
[ROCm/hip commit: a7f453c5b1]
Этот коммит содержится в:
коммит произвёл
GitHub
родитель
5b5f69c310
Коммит
72d3a25bd9
@@ -7524,9 +7524,6 @@ int hipGetStreamDeviceId(hipStream_t stream);
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipStreamBeginCapture(hipStream_t stream, hipStreamCaptureMode mode);
|
||||
|
||||
@@ -7562,9 +7559,6 @@ hipError_t hipStreamBeginCaptureToGraph(hipStream_t stream, hipGraph_t graph,
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipStreamEndCapture(hipStream_t stream, hipGraph_t* pGraph);
|
||||
|
||||
@@ -7577,9 +7571,6 @@ hipError_t hipStreamEndCapture(hipStream_t stream, hipGraph_t* pGraph);
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorStreamCaptureImplicit
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipStreamGetCaptureInfo(hipStream_t stream, hipStreamCaptureStatus* pCaptureStatus,
|
||||
unsigned long long* pId);
|
||||
@@ -7596,9 +7587,6 @@ hipError_t hipStreamGetCaptureInfo(hipStream_t stream, hipStreamCaptureStatus* p
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorStreamCaptureImplicit
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipStreamGetCaptureInfo_v2(hipStream_t stream, hipStreamCaptureStatus* captureStatus_out,
|
||||
unsigned long long* id_out __dparm(0),
|
||||
@@ -7614,9 +7602,6 @@ hipError_t hipStreamGetCaptureInfo_v2(hipStream_t stream, hipStreamCaptureStatus
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorStreamCaptureImplicit
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipStreamIsCapturing(hipStream_t stream, hipStreamCaptureStatus* pCaptureStatus);
|
||||
|
||||
@@ -7630,9 +7615,6 @@ hipError_t hipStreamIsCapturing(hipStream_t stream, hipStreamCaptureStatus* pCap
|
||||
* in enum #hipStreamUpdateCaptureDependenciesFlags.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorIllegalState
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipStreamUpdateCaptureDependencies(hipStream_t stream, hipGraphNode_t* dependencies,
|
||||
size_t numDependencies,
|
||||
@@ -7644,9 +7626,6 @@ hipError_t hipStreamUpdateCaptureDependencies(hipStream_t stream, hipGraphNode_t
|
||||
* @param [in] mode - Pointer to mode value to swap with the current mode.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipThreadExchangeStreamCaptureMode(hipStreamCaptureMode* mode);
|
||||
|
||||
@@ -7658,9 +7637,6 @@ hipError_t hipThreadExchangeStreamCaptureMode(hipStreamCaptureMode* mode);
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorMemoryAllocation
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphCreate(hipGraph_t* pGraph, unsigned int flags);
|
||||
|
||||
@@ -7671,9 +7647,6 @@ hipError_t hipGraphCreate(hipGraph_t* pGraph, unsigned int flags);
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphDestroy(hipGraph_t graph);
|
||||
|
||||
@@ -7686,9 +7659,6 @@ hipError_t hipGraphDestroy(hipGraph_t graph);
|
||||
* @param [in] numDependencies - Number of dependencies to add.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddDependencies(hipGraph_t graph, const hipGraphNode_t* from,
|
||||
const hipGraphNode_t* to, size_t numDependencies);
|
||||
@@ -7702,9 +7672,6 @@ hipError_t hipGraphAddDependencies(hipGraph_t graph, const hipGraphNode_t* from,
|
||||
* @param [in] numDependencies - Number of dependencies to remove.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphRemoveDependencies(hipGraph_t graph, const hipGraphNode_t* from,
|
||||
const hipGraphNode_t* to, size_t numDependencies);
|
||||
@@ -7722,8 +7689,6 @@ hipError_t hipGraphRemoveDependencies(hipGraph_t graph, const hipGraphNode_t* fr
|
||||
* numEdges. Otherwise, numEdges entries will be filled in. If numEdges is higher than the actual
|
||||
* number of edges, the remaining entries in from and to will be set to NULL, and the number of
|
||||
* edges actually returned will be written to numEdges.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphGetEdges(hipGraph_t graph, hipGraphNode_t* from, hipGraphNode_t* to,
|
||||
@@ -7741,8 +7706,6 @@ hipError_t hipGraphGetEdges(hipGraph_t graph, hipGraphNode_t* from, hipGraphNode
|
||||
* Otherwise, numNodes entries will be filled in. If numNodes is higher than the actual number of
|
||||
* nodes, the remaining entries in nodes will be set to NULL, and the number of nodes actually
|
||||
* obtained will be returned in numNodes.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphGetNodes(hipGraph_t graph, hipGraphNode_t* nodes, size_t* numNodes);
|
||||
@@ -7759,8 +7722,6 @@ hipError_t hipGraphGetNodes(hipGraph_t graph, hipGraphNode_t* nodes, size_t* num
|
||||
* pNumRootNodes. Otherwise, pNumRootNodes entries will be filled in. If pNumRootNodes is higher
|
||||
* than the actual number of root nodes, the remaining entries in pRootNodes will be set to NULL,
|
||||
* and the number of nodes actually obtained will be returned in pNumRootNodes.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphGetRootNodes(hipGraph_t graph, hipGraphNode_t* pRootNodes,
|
||||
@@ -7778,8 +7739,6 @@ hipError_t hipGraphGetRootNodes(hipGraph_t graph, hipGraphNode_t* pRootNodes,
|
||||
* pNumDependencies. Otherwise, pNumDependencies entries will be filled in. If pNumDependencies is
|
||||
* higher than the actual number of dependencies, the remaining entries in pDependencies will be set
|
||||
* to NULL, and the number of nodes actually obtained will be returned in pNumDependencies.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphNodeGetDependencies(hipGraphNode_t node, hipGraphNode_t* pDependencies,
|
||||
@@ -7798,8 +7757,6 @@ hipError_t hipGraphNodeGetDependencies(hipGraphNode_t node, hipGraphNode_t* pDep
|
||||
* pNumDependentNodes is higher than the actual number of dependent nodes, the remaining entries in
|
||||
* pDependentNodes will be set to NULL, and the number of nodes actually obtained will be returned
|
||||
* in pNumDependentNodes.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphNodeGetDependentNodes(hipGraphNode_t node, hipGraphNode_t* pDependentNodes,
|
||||
@@ -7812,9 +7769,6 @@ hipError_t hipGraphNodeGetDependentNodes(hipGraphNode_t node, hipGraphNode_t* pD
|
||||
* @param [out] pType - Returns the node's type.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphNodeGetType(hipGraphNode_t node, hipGraphNodeType* pType);
|
||||
|
||||
@@ -7824,9 +7778,6 @@ hipError_t hipGraphNodeGetType(hipGraphNode_t node, hipGraphNodeType* pType);
|
||||
* @param [in] node - graph node to remove
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphDestroyNode(hipGraphNode_t node);
|
||||
|
||||
@@ -7837,9 +7788,6 @@ hipError_t hipGraphDestroyNode(hipGraphNode_t node);
|
||||
* @param [in] originalGraph - original graph to clone from.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorMemoryAllocation
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphClone(hipGraph_t* pGraphClone, hipGraph_t originalGraph);
|
||||
|
||||
@@ -7851,9 +7799,6 @@ hipError_t hipGraphClone(hipGraph_t* pGraphClone, hipGraph_t originalGraph);
|
||||
* @param [in] clonedGraph - Cloned graph to query.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphNodeFindInClone(hipGraphNode_t* pNode, hipGraphNode_t originalNode,
|
||||
hipGraph_t clonedGraph);
|
||||
@@ -7870,9 +7815,6 @@ hipError_t hipGraphNodeFindInClone(hipGraphNode_t* pNode, hipGraphNode_t origina
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorOutOfMemory
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphInstantiate(hipGraphExec_t* pGraphExec, hipGraph_t graph,
|
||||
hipGraphNode_t* pErrorNode, char* pLogBuffer, size_t bufferSize);
|
||||
@@ -7885,9 +7827,7 @@ hipError_t hipGraphInstantiate(hipGraphExec_t* pGraphExec, hipGraph_t graph,
|
||||
* @param [in] flags - Flags to control instantiation.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues. It does not support any of
|
||||
* flag and is behaving as hipGraphInstantiate.
|
||||
* @warning This API does not support any of flag and is behaving as hipGraphInstantiate.
|
||||
*/
|
||||
hipError_t hipGraphInstantiateWithFlags(hipGraphExec_t* pGraphExec, hipGraph_t graph,
|
||||
unsigned long long flags);
|
||||
@@ -7900,8 +7840,6 @@ hipError_t hipGraphInstantiateWithFlags(hipGraphExec_t* pGraphExec, hipGraph_t g
|
||||
* @param [in] instantiateParams - Graph instantiation Params
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*/
|
||||
hipError_t hipGraphInstantiateWithParams(hipGraphExec_t* pGraphExec, hipGraph_t graph,
|
||||
hipGraphInstantiateParams *instantiateParams);
|
||||
@@ -7912,8 +7850,6 @@ hipError_t hipGraphInstantiateWithParams(hipGraphExec_t* pGraphExec, hipGraph_t
|
||||
* @param [in] stream - Instance of stream in which to launch executable graph.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*/
|
||||
hipError_t hipGraphLaunch(hipGraphExec_t graphExec, hipStream_t stream);
|
||||
|
||||
@@ -7924,8 +7860,6 @@ hipError_t hipGraphLaunch(hipGraphExec_t graphExec, hipStream_t stream);
|
||||
* @param [in] stream - Instance of stream to which the executable graph is uploaded to.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*/
|
||||
hipError_t hipGraphUpload(hipGraphExec_t graphExec, hipStream_t stream);
|
||||
|
||||
@@ -7938,8 +7872,7 @@ hipError_t hipGraphUpload(hipGraphExec_t graphExec, hipStream_t stream);
|
||||
* @param [in] numDependencies - Number of dependencies.
|
||||
* @param [in] nodeParams - Pointer to the node parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddNode(hipGraphNode_t *pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t *pDependencies, size_t numDependencies,
|
||||
@@ -7951,8 +7884,7 @@ hipError_t hipGraphAddNode(hipGraphNode_t *pGraphNode, hipGraph_t graph,
|
||||
* @param [in] graphExec - Executable graph to get the flags from.
|
||||
* @param [out] flags - Flags used to instantiate this executable graph.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecGetFlags(hipGraphExec_t graphExec, unsigned long long* flags);
|
||||
|
||||
@@ -7962,8 +7894,7 @@ hipError_t hipGraphExecGetFlags(hipGraphExec_t graphExec, unsigned long long* fl
|
||||
* @param [in] node - Instance of the node to set parameters for.
|
||||
* @param [in] nodeParams - Pointer to the parameters to be set.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidDeviceFunction, #hipErrorNotSupported.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphNodeSetParams(hipGraphNode_t node, hipGraphNodeParams *nodeParams);
|
||||
|
||||
@@ -7974,8 +7905,7 @@ hipError_t hipGraphNodeSetParams(hipGraphNode_t node, hipGraphNodeParams *nodePa
|
||||
* @param [in] node - Instance of the node to set parameters to.
|
||||
* @param [in] nodeParams - Pointer to the parameters to be set.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidDeviceFunction, #hipErrorNotSupported.
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecNodeSetParams(hipGraphExec_t graphExec, hipGraphNode_t node, hipGraphNodeParams* nodeParams);
|
||||
|
||||
@@ -7986,8 +7916,6 @@ hipError_t hipGraphExecNodeSetParams(hipGraphExec_t graphExec, hipGraphNode_t no
|
||||
*
|
||||
* @returns #hipSuccess.
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*/
|
||||
hipError_t hipGraphExecDestroy(hipGraphExec_t graphExec);
|
||||
|
||||
@@ -8002,8 +7930,6 @@ hipError_t hipGraphExecDestroy(hipGraphExec_t graphExec);
|
||||
* @param [in] updateResult_out - Return code whether the graph update was performed.
|
||||
* @returns #hipSuccess, #hipErrorGraphExecUpdateFailure
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*/
|
||||
hipError_t hipGraphExecUpdate(hipGraphExec_t hGraphExec, hipGraph_t hGraph,
|
||||
hipGraphNode_t* hErrorNode_out,
|
||||
@@ -8018,8 +7944,7 @@ hipError_t hipGraphExecUpdate(hipGraphExec_t hGraphExec, hipGraph_t hGraph,
|
||||
* @param [in] numDependencies - The number of the dependencies.
|
||||
* @param [in] pNodeParams - Pointer to the parameters of the kernel execution node.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidDeviceFunction
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddKernelNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8031,8 +7956,7 @@ hipError_t hipGraphAddKernelNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] node - instance of the node to get parameters from.
|
||||
* @param [out] pNodeParams - pointer to the parameters
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphKernelNodeGetParams(hipGraphNode_t node, hipKernelNodeParams* pNodeParams);
|
||||
|
||||
@@ -8042,8 +7966,7 @@ hipError_t hipGraphKernelNodeGetParams(hipGraphNode_t node, hipKernelNodeParams*
|
||||
* @param [in] node - Instance of the node to set parameters of.
|
||||
* @param [in] pNodeParams - const pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphKernelNodeSetParams(hipGraphNode_t node, const hipKernelNodeParams* pNodeParams);
|
||||
|
||||
@@ -8054,8 +7977,7 @@ hipError_t hipGraphKernelNodeSetParams(hipGraphNode_t node, const hipKernelNodeP
|
||||
* @param [in] node - Instance of the node to set parameters of.
|
||||
* @param [in] pNodeParams - const pointer to the kernel node parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecKernelNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
const hipKernelNodeParams* pNodeParams);
|
||||
@@ -8070,8 +7992,7 @@ hipError_t hipGraphExecKernelNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNo
|
||||
* @param [in] copyParams - const pointer to the parameters for the memory copy.
|
||||
* @param [in] ctx - context related to current device.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDrvGraphAddMemcpyNode(hipGraphNode_t* phGraphNode, hipGraph_t hGraph,
|
||||
const hipGraphNode_t* dependencies,
|
||||
@@ -8086,8 +8007,7 @@ hipError_t hipDrvGraphAddMemcpyNode(hipGraphNode_t* phGraphNode, hipGraph_t hGra
|
||||
* @param [in] numDependencies - The number of dependencies.
|
||||
* @param [in] pCopyParams - const pointer to the parameters for the memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddMemcpyNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8098,8 +8018,7 @@ hipError_t hipGraphAddMemcpyNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] node - instance of the node to get parameters from.
|
||||
* @param [out] pNodeParams - pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemcpyNodeGetParams(hipGraphNode_t node, hipMemcpy3DParms* pNodeParams);
|
||||
|
||||
@@ -8109,8 +8028,7 @@ hipError_t hipGraphMemcpyNodeGetParams(hipGraphNode_t node, hipMemcpy3DParms* pN
|
||||
* @param [in] node - instance of the node to set parameters to.
|
||||
* @param [in] pNodeParams - const pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemcpyNodeSetParams(hipGraphNode_t node, const hipMemcpy3DParms* pNodeParams);
|
||||
|
||||
@@ -8121,8 +8039,7 @@ hipError_t hipGraphMemcpyNodeSetParams(hipGraphNode_t node, const hipMemcpy3DPar
|
||||
* @param [in] attr - The attribute type to be set.
|
||||
* @param [in] value - const pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphKernelNodeSetAttribute(hipGraphNode_t hNode, hipKernelNodeAttrID attr,
|
||||
const hipKernelNodeAttrValue* value);
|
||||
@@ -8133,8 +8050,7 @@ hipError_t hipGraphKernelNodeSetAttribute(hipGraphNode_t hNode, hipKernelNodeAtt
|
||||
* @param [in] attr - The attribute type to be set.
|
||||
* @param [in] value - const pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphKernelNodeGetAttribute(hipGraphNode_t hNode, hipKernelNodeAttrID attr,
|
||||
hipKernelNodeAttrValue* value);
|
||||
@@ -8145,8 +8061,7 @@ hipError_t hipGraphKernelNodeGetAttribute(hipGraphNode_t hNode, hipKernelNodeAtt
|
||||
* @param [in] node - Instance of the node to set parameters of.
|
||||
* @param [in] pNodeParams - const pointer to the kernel node parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecMemcpyNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
hipMemcpy3DParms* pNodeParams);
|
||||
@@ -8163,8 +8078,7 @@ hipError_t hipGraphExecMemcpyNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNo
|
||||
* @param [in] count - Size of the memory to copy.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddMemcpyNode1D(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8179,8 +8093,7 @@ hipError_t hipGraphAddMemcpyNode1D(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] count - Size of the memory to copy.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemcpyNodeSetParams1D(hipGraphNode_t node, void* dst, const void* src,
|
||||
size_t count, hipMemcpyKind kind);
|
||||
@@ -8196,8 +8109,7 @@ hipError_t hipGraphMemcpyNodeSetParams1D(hipGraphNode_t node, void* dst, const v
|
||||
* @param [in] count - Size of the memory to copy.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecMemcpyNodeSetParams1D(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
void* dst, const void* src, size_t count,
|
||||
@@ -8216,8 +8128,7 @@ hipError_t hipGraphExecMemcpyNodeSetParams1D(hipGraphExec_t hGraphExec, hipGraph
|
||||
* @param [in] offset - Offset from start of symbol in bytes.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddMemcpyNodeFromSymbol(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies,
|
||||
@@ -8234,8 +8145,7 @@ hipError_t hipGraphAddMemcpyNodeFromSymbol(hipGraphNode_t* pGraphNode, hipGraph_
|
||||
* @param [in] offset - Offset from start of symbol in bytes.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemcpyNodeSetParamsFromSymbol(hipGraphNode_t node, void* dst, const void* symbol,
|
||||
size_t count, size_t offset, hipMemcpyKind kind);
|
||||
@@ -8252,8 +8162,7 @@ hipError_t hipGraphMemcpyNodeSetParamsFromSymbol(hipGraphNode_t node, void* dst,
|
||||
* @param [in] offset - Offset from start of symbol in bytes.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecMemcpyNodeSetParamsFromSymbol(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
void* dst, const void* symbol, size_t count,
|
||||
@@ -8272,8 +8181,7 @@ hipError_t hipGraphExecMemcpyNodeSetParamsFromSymbol(hipGraphExec_t hGraphExec,
|
||||
* @param [in] offset - Offset from start of symbol in bytes.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddMemcpyNodeToSymbol(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies,
|
||||
@@ -8291,8 +8199,7 @@ hipError_t hipGraphAddMemcpyNodeToSymbol(hipGraphNode_t* pGraphNode, hipGraph_t
|
||||
* @param [in] offset - Offset from start of symbol in bytes.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemcpyNodeSetParamsToSymbol(hipGraphNode_t node, const void* symbol,
|
||||
const void* src, size_t count, size_t offset,
|
||||
@@ -8310,8 +8217,7 @@ hipError_t hipGraphMemcpyNodeSetParamsToSymbol(hipGraphNode_t node, const void*
|
||||
* @param [in] offset - Offset from start of symbol in bytes.
|
||||
* @param [in] kind - Type of memory copy.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecMemcpyNodeSetParamsToSymbol(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
const void* symbol, const void* src,
|
||||
@@ -8326,8 +8232,7 @@ hipError_t hipGraphExecMemcpyNodeSetParamsToSymbol(hipGraphExec_t hGraphExec, hi
|
||||
* @param [in] numDependencies - Number of dependencies.
|
||||
* @param [in] pMemsetParams - const pointer to the parameters for the memory set.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddMemsetNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8339,8 +8244,7 @@ hipError_t hipGraphAddMemsetNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] node - Instance of the node to get parameters of.
|
||||
* @param [out] pNodeParams - Pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemsetNodeGetParams(hipGraphNode_t node, hipMemsetParams* pNodeParams);
|
||||
|
||||
@@ -8350,8 +8254,7 @@ hipError_t hipGraphMemsetNodeGetParams(hipGraphNode_t node, hipMemsetParams* pNo
|
||||
* @param [in] node - Instance of the node to set parameters of.
|
||||
* @param [in] pNodeParams - Pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemsetNodeSetParams(hipGraphNode_t node, const hipMemsetParams* pNodeParams);
|
||||
|
||||
@@ -8362,8 +8265,7 @@ hipError_t hipGraphMemsetNodeSetParams(hipGraphNode_t node, const hipMemsetParam
|
||||
* @param [in] node - Instance of the node to set parameters of.
|
||||
* @param [in] pNodeParams - Pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecMemsetNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
const hipMemsetParams* pNodeParams);
|
||||
@@ -8377,8 +8279,7 @@ hipError_t hipGraphExecMemsetNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNo
|
||||
* @param [in] numDependencies - Number of dependencies.
|
||||
* @param [in] pNodeParams - Pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddHostNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8390,8 +8291,7 @@ hipError_t hipGraphAddHostNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] node - Instance of the node to get parameters of.
|
||||
* @param [out] pNodeParams - Pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphHostNodeGetParams(hipGraphNode_t node, hipHostNodeParams* pNodeParams);
|
||||
|
||||
@@ -8401,8 +8301,7 @@ hipError_t hipGraphHostNodeGetParams(hipGraphNode_t node, hipHostNodeParams* pNo
|
||||
* @param [in] node - Instance of the node to set parameters of.
|
||||
* @param [in] pNodeParams - Pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphHostNodeSetParams(hipGraphNode_t node, const hipHostNodeParams* pNodeParams);
|
||||
|
||||
@@ -8413,8 +8312,7 @@ hipError_t hipGraphHostNodeSetParams(hipGraphNode_t node, const hipHostNodeParam
|
||||
* @param [in] node - Instance of the node to set parameters of.
|
||||
* @param [in] pNodeParams - Pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecHostNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
const hipHostNodeParams* pNodeParams);
|
||||
@@ -8428,8 +8326,7 @@ hipError_t hipGraphExecHostNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode
|
||||
* @param [in] numDependencies - Number of dependencies.
|
||||
* @param [in] childGraph - Graph to clone into this node
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddChildGraphNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8441,8 +8338,7 @@ hipError_t hipGraphAddChildGraphNode(hipGraphNode_t* pGraphNode, hipGraph_t grap
|
||||
* @param [in] node - Instance of the node to get child graph of.
|
||||
* @param [out] pGraph - Pointer to get the graph.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphChildGraphNodeGetGraph(hipGraphNode_t node, hipGraph_t* pGraph);
|
||||
|
||||
@@ -8453,8 +8349,7 @@ hipError_t hipGraphChildGraphNodeGetGraph(hipGraphNode_t node, hipGraph_t* pGrap
|
||||
* @param [in] node - node from the graph which was used to instantiate graphExec.
|
||||
* @param [in] childGraph - child graph with updated parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecChildGraphNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t node,
|
||||
hipGraph_t childGraph);
|
||||
@@ -8467,8 +8362,7 @@ hipError_t hipGraphExecChildGraphNodeSetParams(hipGraphExec_t hGraphExec, hipGra
|
||||
* @param [in] pDependencies - const pointer to the node dependencies.
|
||||
* @param [in] numDependencies - Number of dependencies.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddEmptyNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies);
|
||||
@@ -8483,8 +8377,7 @@ hipError_t hipGraphAddEmptyNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] numDependencies - Number of dependencies.
|
||||
* @param [in] event - Event of the node.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddEventRecordNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8496,8 +8389,7 @@ hipError_t hipGraphAddEventRecordNode(hipGraphNode_t* pGraphNode, hipGraph_t gra
|
||||
* @param [in] node - Instance of the node to get event of.
|
||||
* @param [out] event_out - Pointer to return the event.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphEventRecordNodeGetEvent(hipGraphNode_t node, hipEvent_t* event_out);
|
||||
|
||||
@@ -8507,8 +8399,7 @@ hipError_t hipGraphEventRecordNodeGetEvent(hipGraphNode_t node, hipEvent_t* even
|
||||
* @param [in] node - Instance of the node to set event to.
|
||||
* @param [in] event - Pointer to the event.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphEventRecordNodeSetEvent(hipGraphNode_t node, hipEvent_t event);
|
||||
|
||||
@@ -8519,8 +8410,7 @@ hipError_t hipGraphEventRecordNodeSetEvent(hipGraphNode_t node, hipEvent_t event
|
||||
* @param [in] hNode - node from the graph which was used to instantiate graphExec.
|
||||
* @param [in] event - pointer to the event.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecEventRecordNodeSetEvent(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
hipEvent_t event);
|
||||
@@ -8534,8 +8424,7 @@ hipError_t hipGraphExecEventRecordNodeSetEvent(hipGraphExec_t hGraphExec, hipGra
|
||||
* @param [in] numDependencies - Number of dependencies.
|
||||
* @param [in] event - Event for the node.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddEventWaitNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8548,8 +8437,7 @@ hipError_t hipGraphAddEventWaitNode(hipGraphNode_t* pGraphNode, hipGraph_t graph
|
||||
* @param [in] node - Instance of the node to get event of.
|
||||
* @param [out] event_out - Pointer to return the event.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphEventWaitNodeGetEvent(hipGraphNode_t node, hipEvent_t* event_out);
|
||||
|
||||
@@ -8559,8 +8447,7 @@ hipError_t hipGraphEventWaitNodeGetEvent(hipGraphNode_t node, hipEvent_t* event_
|
||||
* @param [in] node - Instance of the node to set event of.
|
||||
* @param [in] event - Pointer to the event.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphEventWaitNodeSetEvent(hipGraphNode_t node, hipEvent_t event);
|
||||
|
||||
@@ -8571,8 +8458,7 @@ hipError_t hipGraphEventWaitNodeSetEvent(hipGraphNode_t node, hipEvent_t event);
|
||||
* @param [in] hNode - node from the graph which was used to instantiate graphExec.
|
||||
* @param [in] event - pointer to the event.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecEventWaitNodeSetEvent(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
hipEvent_t event);
|
||||
@@ -8586,8 +8472,7 @@ hipError_t hipGraphExecEventWaitNodeSetEvent(hipGraphExec_t hGraphExec, hipGraph
|
||||
* @param [in] numDependencies - The number of dependencies
|
||||
* @param [in, out] pNodeParams - Node parameters for memory allocation, returns a pointer to the allocated memory.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddMemAllocNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies, hipMemAllocNodeParams* pNodeParams);
|
||||
@@ -8598,8 +8483,7 @@ hipError_t hipGraphAddMemAllocNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] node - Memory allocation node to query
|
||||
* @param [out] pNodeParams - Parameters for the specified memory allocation node
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemAllocNodeGetParams(hipGraphNode_t node, hipMemAllocNodeParams* pNodeParams);
|
||||
|
||||
@@ -8612,8 +8496,7 @@ hipError_t hipGraphMemAllocNodeGetParams(hipGraphNode_t node, hipMemAllocNodePar
|
||||
* @param [in] numDependencies - The number of dependencies
|
||||
* @param [in] dev_ptr - Pointer to the memory to be freed
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddMemFreeNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies, void* dev_ptr);
|
||||
@@ -8624,8 +8507,7 @@ hipError_t hipGraphAddMemFreeNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
* @param [in] node - Memory free node to query
|
||||
* @param [out] dev_ptr - Device pointer of the specified memory free node
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphMemFreeNodeGetParams(hipGraphNode_t node, void* dev_ptr);
|
||||
|
||||
@@ -8636,8 +8518,7 @@ hipError_t hipGraphMemFreeNodeGetParams(hipGraphNode_t node, void* dev_ptr);
|
||||
* @param [in] attr - Attribute type to be queried
|
||||
* @param [out] value - Value of the queried attribute
|
||||
* @returns #hipSuccess, #hipErrorInvalidDevice
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDeviceGetGraphMemAttribute(int device, hipGraphMemAttributeType attr, void* value);
|
||||
|
||||
@@ -8648,8 +8529,7 @@ hipError_t hipDeviceGetGraphMemAttribute(int device, hipGraphMemAttributeType at
|
||||
* @param [in] attr - Attribute type to be set.
|
||||
* @param [in] value - Value of the attribute.
|
||||
* @returns #hipSuccess, #hipErrorInvalidDevice
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDeviceSetGraphMemAttribute(int device, hipGraphMemAttributeType attr, void* value);
|
||||
|
||||
@@ -8659,8 +8539,6 @@ hipError_t hipDeviceSetGraphMemAttribute(int device, hipGraphMemAttributeType at
|
||||
* @param [in] device - Device for which memory should be trimmed
|
||||
* @returns #hipSuccess, #hipErrorInvalidDevice
|
||||
*
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*/
|
||||
hipError_t hipDeviceGraphMemTrim(int device);
|
||||
|
||||
@@ -8673,8 +8551,7 @@ hipError_t hipDeviceGraphMemTrim(int device);
|
||||
* @param [in] initialRefcount - reference to resource.
|
||||
* @param [in] flags - flags passed to API.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipUserObjectCreate(hipUserObject_t* object_out, void* ptr, hipHostFn_t destroy,
|
||||
unsigned int initialRefcount, unsigned int flags);
|
||||
@@ -8685,8 +8562,7 @@ hipError_t hipUserObjectCreate(hipUserObject_t* object_out, void* ptr, hipHostFn
|
||||
* @param [in] object - pointer to instace of userobj.
|
||||
* @param [in] count - reference to resource to be retained.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipUserObjectRelease(hipUserObject_t object, unsigned int count __dparm(1));
|
||||
|
||||
@@ -8696,8 +8572,7 @@ hipError_t hipUserObjectRelease(hipUserObject_t object, unsigned int count __dpa
|
||||
* @param [in] object - pointer to instace of userobj.
|
||||
* @param [in] count - reference to resource to be retained.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipUserObjectRetain(hipUserObject_t object, unsigned int count __dparm(1));
|
||||
|
||||
@@ -8709,8 +8584,7 @@ hipError_t hipUserObjectRetain(hipUserObject_t object, unsigned int count __dpar
|
||||
* @param [in] count - reference to resource to be retained.
|
||||
* @param [in] flags - flags passed to API.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphRetainUserObject(hipGraph_t graph, hipUserObject_t object,
|
||||
unsigned int count __dparm(1), unsigned int flags __dparm(0));
|
||||
@@ -8722,8 +8596,7 @@ hipError_t hipGraphRetainUserObject(hipGraph_t graph, hipUserObject_t object,
|
||||
* @param [in] object - pointer to instace of userobj.
|
||||
* @param [in] count - reference to resource to be retained.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphReleaseUserObject(hipGraph_t graph, hipUserObject_t object,
|
||||
unsigned int count __dparm(1));
|
||||
@@ -8735,8 +8608,7 @@ hipError_t hipGraphReleaseUserObject(hipGraph_t graph, hipUserObject_t object,
|
||||
* @param [in] path - path to write the DOT file.
|
||||
* @param [in] flags - Flags from hipGraphDebugDotFlags to get additional node information.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue, #hipErrorOperatingSystem
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphDebugDotPrint(hipGraph_t graph, const char* path, unsigned int flags);
|
||||
|
||||
@@ -8751,8 +8623,7 @@ hipError_t hipGraphDebugDotPrint(hipGraph_t graph, const char* path, unsigned in
|
||||
* For list of attributes see ::hipKernelNodeAttrID.
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidContext
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphKernelNodeCopyAttributes(hipGraphNode_t hSrc, hipGraphNode_t hDst);
|
||||
|
||||
@@ -8775,8 +8646,7 @@ hipError_t hipGraphKernelNodeCopyAttributes(hipGraphNode_t hSrc, hipGraphNode_t
|
||||
* @param [in] isEnabled - Node is enabled if != 0, otherwise the node is disabled.
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue,
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphNodeSetEnabled(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
unsigned int isEnabled);
|
||||
@@ -8797,8 +8667,7 @@ hipError_t hipGraphNodeSetEnabled(hipGraphExec_t hGraphExec, hipGraphNode_t hNod
|
||||
* @param [out] isEnabled - Location to return the enabled status of the node.
|
||||
*
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphNodeGetEnabled(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
unsigned int* isEnabled);
|
||||
@@ -8812,8 +8681,7 @@ hipError_t hipGraphNodeGetEnabled(hipGraphExec_t hGraphExec, hipGraphNode_t hNod
|
||||
* @param [in] numDependencies - the number of the dependencies.
|
||||
* @param [in] nodeParams -pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddExternalSemaphoresWaitNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8828,8 +8696,7 @@ hipError_t hipGraphAddExternalSemaphoresWaitNode(hipGraphNode_t* pGraphNode, hip
|
||||
* @param [in] numDependencies - the number of the dependencies.
|
||||
* @param [in] nodeParams -pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphAddExternalSemaphoresSignalNode(hipGraphNode_t* pGraphNode, hipGraph_t graph,
|
||||
const hipGraphNode_t* pDependencies, size_t numDependencies,
|
||||
@@ -8840,8 +8707,7 @@ hipError_t hipGraphAddExternalSemaphoresSignalNode(hipGraphNode_t* pGraphNode, h
|
||||
* @param [in] hNode - Node from the graph from which graphExec was instantiated.
|
||||
* @param [in] nodeParams - Pointer to the params to be set.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExternalSemaphoresSignalNodeSetParams(hipGraphNode_t hNode,
|
||||
const hipExternalSemaphoreSignalNodeParams* nodeParams);
|
||||
@@ -8851,8 +8717,7 @@ hipError_t hipGraphExternalSemaphoresSignalNodeSetParams(hipGraphNode_t hNode,
|
||||
* @param [in] hNode - Node from the graph from which graphExec was instantiated.
|
||||
* @param [in] nodeParams - Pointer to the params to be set.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExternalSemaphoresWaitNodeSetParams(hipGraphNode_t hNode,
|
||||
const hipExternalSemaphoreWaitNodeParams* nodeParams);
|
||||
@@ -8862,8 +8727,7 @@ hipError_t hipGraphExternalSemaphoresWaitNodeSetParams(hipGraphNode_t hNode,
|
||||
* @param [in] hNode - Node from the graph from which graphExec was instantiated.
|
||||
* @param [out] params_out - Pointer to params.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExternalSemaphoresSignalNodeGetParams(hipGraphNode_t hNode,
|
||||
hipExternalSemaphoreSignalNodeParams* params_out);
|
||||
@@ -8873,8 +8737,7 @@ hipError_t hipGraphExternalSemaphoresSignalNodeGetParams(hipGraphNode_t hNode,
|
||||
* @param [in] hNode - Node from the graph from which graphExec was instantiated.
|
||||
* @param [out] params_out - Pointer to params.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExternalSemaphoresWaitNodeGetParams(hipGraphNode_t hNode,
|
||||
hipExternalSemaphoreWaitNodeParams* params_out);
|
||||
@@ -8885,8 +8748,7 @@ hipError_t hipGraphExternalSemaphoresWaitNodeGetParams(hipGraphNode_t hNode,
|
||||
* @param [in] hNode - Node from the graph from which graphExec was instantiated.
|
||||
* @param [in] nodeParams - Pointer to the params to be set.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecExternalSemaphoresSignalNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
const hipExternalSemaphoreSignalNodeParams* nodeParams);
|
||||
@@ -8897,8 +8759,7 @@ hipError_t hipGraphExecExternalSemaphoresSignalNodeSetParams(hipGraphExec_t hGra
|
||||
* @param [in] hNode - Node from the graph from which graphExec was instantiated.
|
||||
* @param [in] nodeParams - Pointer to the params to be set.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipGraphExecExternalSemaphoresWaitNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
const hipExternalSemaphoreWaitNodeParams* nodeParams);
|
||||
@@ -8909,8 +8770,7 @@ hipError_t hipGraphExecExternalSemaphoresWaitNodeSetParams(hipGraphExec_t hGraph
|
||||
* @param [in] hNode - instance of the node to get parameters from.
|
||||
* @param [out] nodeParams - pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDrvGraphMemcpyNodeGetParams(hipGraphNode_t hNode, HIP_MEMCPY3D* nodeParams);
|
||||
|
||||
@@ -8920,8 +8780,7 @@ hipError_t hipDrvGraphMemcpyNodeGetParams(hipGraphNode_t hNode, HIP_MEMCPY3D* no
|
||||
* @param [in] hNode - instance of the node to Set parameters for.
|
||||
* @param [out] nodeParams - pointer to the parameters.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDrvGraphMemcpyNodeSetParams(hipGraphNode_t hNode, const HIP_MEMCPY3D* nodeParams);
|
||||
|
||||
@@ -8935,8 +8794,7 @@ hipError_t hipDrvGraphMemcpyNodeSetParams(hipGraphNode_t hNode, const HIP_MEMCPY
|
||||
* @param [in] memsetParams - const pointer to the parameters for the memory set.
|
||||
* @param [in] ctx - cotext related to current device.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDrvGraphAddMemsetNode(hipGraphNode_t* phGraphNode, hipGraph_t hGraph,
|
||||
const hipGraphNode_t* dependencies, size_t numDependencies,
|
||||
@@ -8951,8 +8809,7 @@ hipError_t hipDrvGraphAddMemsetNode(hipGraphNode_t* phGraphNode, hipGraph_t hGra
|
||||
* @param [in] numDependencies - The number of dependencies
|
||||
* @param [in] dptr - Pointer to the memory to be freed
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDrvGraphAddMemFreeNode(hipGraphNode_t* phGraphNode, hipGraph_t hGraph,
|
||||
const hipGraphNode_t* dependencies, size_t numDependencies,
|
||||
@@ -8966,8 +8823,7 @@ hipError_t hipDrvGraphAddMemFreeNode(hipGraphNode_t* phGraphNode, hipGraph_t hGr
|
||||
* @param [in] copyParams - const pointer to the memcpy node params.
|
||||
* @param [in] ctx - cotext related to current device.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDrvGraphExecMemcpyNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
const HIP_MEMCPY3D* copyParams, hipCtx_t ctx);
|
||||
@@ -8980,8 +8836,7 @@ hipError_t hipDrvGraphExecMemcpyNodeSetParams(hipGraphExec_t hGraphExec, hipGrap
|
||||
* @param [in] memsetParams - pointer to the parameters.
|
||||
* @param [in] ctx - cotext related to current device.
|
||||
* @returns #hipSuccess, #hipErrorInvalidValue
|
||||
* @warning This API is marked as Beta. While this feature is complete, it can
|
||||
* change and might have outstanding issues.
|
||||
*
|
||||
*/
|
||||
hipError_t hipDrvGraphExecMemsetNodeSetParams(hipGraphExec_t hGraphExec, hipGraphNode_t hNode,
|
||||
const hipMemsetParams* memsetParams, hipCtx_t ctx);
|
||||
|
||||
Ссылка в новой задаче
Block a user